@@ -40,8 +40,6 @@
 
 #include <gtk/gtk.h>
 
-#include <gconf/gconf-client.h>
-
 #include "burn-basics.h"
 #include "burn-plugin-manager.h"
 #include "brasero-medium-selection-priv.h"
@@ -147,6 +145,7 @@ brasero_dest_selection_output_changed (BraseroSessionCfg *session,
 
 static void
 brasero_dest_selection_flags_changed (BraseroBurnSession *session,
+                                      GParamSpec *pspec,
 				      BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
@@ -242,11 +241,8 @@ brasero_dest_selection_medium_added (GtkTreeModel *model,
 static void
 brasero_dest_selection_init (BraseroDestSelection *object)
 {
-	BraseroDestSelectionPrivate *priv;
 	GtkTreeModel *model;
 
-	priv = BRASERO_DEST_SELECTION_PRIVATE (object);
-
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (object));
 	g_signal_connect (model,
 	                  "row-inserted",
@@ -261,7 +257,8 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 	 * There is one exception though, when we're copying media and when the
 	 * burning device is the same as the dest device. */
 	brasero_medium_selection_show_media_type (BRASERO_MEDIUM_SELECTION (object),
-						  BRASERO_MEDIA_TYPE_WRITABLE);
+						  BRASERO_MEDIA_TYPE_WRITABLE|
+						  BRASERO_MEDIA_TYPE_FILE);
 
 	/* This is to know when the user changed it on purpose */
 	g_signal_connect (object,
@@ -446,18 +443,29 @@ brasero_dest_selection_set_session (BraseroDestSelection *selection,
 	if (brasero_burn_session_get_flags (session) & BRASERO_BURN_FLAG_MERGE) {
 		BraseroDrive *drive;
 
+		/* Prevent automatic resetting since a drive was set */
+		priv->user_changed = TRUE;
+
 		drive = brasero_burn_session_get_burner (session);
 		brasero_medium_selection_set_active (BRASERO_MEDIUM_SELECTION (selection),
 						     brasero_drive_get_medium (drive));
 	}
 	else {
-		BraseroMedium *medium;
+		BraseroDrive *burner;
 
-		medium = brasero_medium_selection_get_active (BRASERO_MEDIUM_SELECTION (selection));
-		if (medium) {
-			brasero_burn_session_set_burner (session, brasero_medium_get_drive (medium));
-			g_object_unref (medium);
+		/* Only try to set a better drive if there isn't one already set */
+		burner = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (priv->session));
+		if (burner) {
+			BraseroMedium *medium;
+
+			/* Prevent automatic resetting since a drive was set */
+			priv->user_changed = TRUE;
+
+			medium = brasero_drive_get_medium (burner);
+			brasero_medium_selection_set_active (BRASERO_MEDIUM_SELECTION (selection), medium);
 		}
+		else
+			brasero_dest_selection_choose_best (BRASERO_DEST_SELECTION (selection));
 	}
 
 	g_signal_connect (session,
@@ -469,7 +477,7 @@ brasero_dest_selection_set_session (BraseroDestSelection *selection,
 			  G_CALLBACK (brasero_dest_selection_output_changed),
 			  selection);
 	g_signal_connect (session,
-			  "flags-changed",
+			  "notify::flags",
 			  G_CALLBACK (brasero_dest_selection_flags_changed),
 			  selection);
 
@@ -482,11 +490,8 @@ brasero_dest_selection_set_property (GObject *object,
 				     const GValue *value,
 				     GParamSpec *pspec)
 {
-	BraseroDestSelectionPrivate *priv;
 	BraseroBurnSession *session;
 
-	priv = BRASERO_DEST_SELECTION_PRIVATE (object);
-
 	switch (property_id) {
 	case PROP_SESSION: /* Readable and only writable at creation time */
 		/* NOTE: no need to unref a potential previous session since
@@ -572,6 +577,9 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (selection);
 
+	if (!priv->session)
+		return NULL;
+
 	medium_name = brasero_volume_get_name (BRASERO_VOLUME (medium));
 	if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_FILE) {
 		gchar *path;
